@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2014 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,7 +49,6 @@
 
 package com.openexchange.halo.pictures;
 
-import javax.servlet.http.HttpServletResponse;
 import com.openexchange.ajax.container.ByteArrayFileHolder;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
@@ -61,6 +60,7 @@ import com.openexchange.halo.ContactHalo;
 import com.openexchange.halo.Picture;
 import com.openexchange.server.ServiceExceptionCode;
 import com.openexchange.server.ServiceLookup;
+import com.openexchange.tools.servlet.http.Tools;
 import com.openexchange.tools.session.ServerSession;
 
 
@@ -85,12 +85,12 @@ public class GetPictureAction implements ETagAwareAJAXActionService {
         if (picture == null) {
             // 404 - Not Found
             AJAXRequestResult result = new AJAXRequestResult();
-            result.setHttpStatusCode(HttpServletResponse.SC_NOT_FOUND);
+            result.setHttpStatusCode(404);
             return result;
         }
         AJAXRequestResult result = new AJAXRequestResult(picture.getFileHolder(), "file");
 
-        setETag(picture.getEtag(), 1000, result);
+        setETag(picture.getEtag(), Tools.getDefaultImageExpiry(), result);
 
         return result;
     }
@@ -102,7 +102,6 @@ public class GetPictureAction implements ETagAwareAJAXActionService {
             return false;
         }
         if (pictureETag.equals(clientETag)) {
-            request.setExpires(1000);
             return true;
         }
         return false;
